#
# spec file for package trytond_account
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2016-2024 Dr. Axel Braun
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#

%if 0%{?suse_version} >= 1550
%define pythons python3
%define mypython python3
%define mysitelib %python3_sitelib
%else
%{?sle15_python_module_pythons}
%define mypython %pythons
%define mysitelib %{expand:%%%{mypython}_sitelib}
%endif

%define majorver 6.0
Name:           trytond_account
Version:        %{majorver}.28
Release:        bp156.2.9.1
Summary:        The "account" module for the Tryton ERP system
License:        GPL-3.0-or-later
Group:          Productivity/Office/Management
URL:            http://www.tryton.org/
Source:         http://downloads.tryton.org/%{majorver}/%{name}-%{version}.tar.gz
## Source2:        http://downloads.tryton.org/%{majorver}/%{name}-%{version}.tar.gz.asc
## Source3:        https://keybase.io/cedrickrier/pgp_keys.asc?fingerprint=7C5A4360F6DF81ABA91FD54D6FF50AFE03489130#/%{name}.keyring
BuildRequires:  %{mypython}-pip
BuildRequires:  %{mypython}-devel
BuildRequires:  %{mypython}-setuptools
BuildRequires:  %{mypython}-wheel
BuildRequires:  fdupes
BuildRequires:  python-rpm-generators
BuildRequires:  python-rpm-macros

Requires:       trytond
Requires:       trytond_company
Requires:       trytond_currency
Requires:       trytond_party
BuildArch:      noarch

%description
The accounting module of the Tryton application platform.
It defines fundamentals for most of accounting needs, such as fiscal year,
period, account type, journal, tax code and more.

%prep
%setup -q

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{mysitelib}

%files
%defattr(-,root,root)
%{mysitelib}/tryton*

%changelog
* Thu Jan  2 2025 Axel Braun <axel.braun@gmx.de>
- Version 6.0.28 - Bugfix Release
* Tue Sep 17 2024 Axel Braun <axel.braun@gmx.de>
- Version 6.0.27 - Bugfix Release
* Tue Jul  2 2024 Axel Braun <axel.braun@gmx.de>
- Version 6.0.26 - Bugfix Release
* Sun May 19 2024 Axel Braun <axel.braun@gmx.de>
- Version 6.0.25 - Bugfix Release
* Tue May  7 2024 Axel Braun <axel.braun@gmx.de>
- Version 6.0.24 - Bugfix Release
* Mon Apr 29 2024 Axel Braun <axel.braun@gmx.de>
- sources are not signed anymore
* Sat Feb  3 2024 Axel Braun <axel.braun@gmx.de>
- Version 6.0.21 - Bugfix Release
* Sat Jan 13 2024 Axel Braun <axel.braun@gmx.de>
- Switch to wheel and %%{?sle15_python_module_pythons}
* Sat Dec 23 2023 Axel Braun <axel.braun@gmx.de>
- Version 6.0.20 - Bugfix Release
* Sat Nov  4 2023 Axel Braun <axel.braun@gmx.de>
- Version 6.0.19 - Bugfix Release
* Thu Oct 19 2023 Daniel Garcia Moreno <daniel.garcia@suse.com>
- Remove %%python3_install prefix and root options, that's included in
  the macro by default.
* Thu Sep  7 2023 Axel Braun <axel.braun@gmx.de>
- Version 6.0.18 - Bugfix Release
* Sat May 20 2023 Axel Braun <axel.braun@gmx.de>
- Version 6.0.17 - Bugfix Release
* Sun Feb 19 2023 Axel Braun <axel.braun@gmx.de>
- Version 6.0.15 - Bugfix Release
* Mon Feb  6 2023 Axel Braun <axel.braun@gmx.de>
- Version 6.0.14 - Bugfix Release
* Thu Aug 18 2022 Axel Braun <axel.braun@gmx.de>
- Version 6.0.13 - Bugfix Release
* Thu Aug  4 2022 Axel Braun <axel.braun@gmx.de>
- Version 6.0.12 - Bugfix Release
* Sat Jun  4 2022 Axel Braun <axel.braun@gmx.de>
- Version 6.0.11 - Bugfix Release
* Mon Apr 18 2022 Axel Braun <axel.braun@gmx.de>
- Version 6.0.10 - Bugfix Release
* Wed Mar  2 2022 Axel Braun <axel.braun@gmx.de>
- Version 6.0.9 - Bugfix Release
* Fri Feb 18 2022 Axel Braun <axel.braun@gmx.de>
- Version 6.0.8 - Bugfix Release
* Sat Feb 12 2022 Axel Braun <axel.braun@gmx.de>
- Version bump to Tryton 6.0 series
* Tue Feb  1 2022 Axel Braun <axel.braun@gmx.de>
- Version 5.0.21 - Bugfix Release
* Mon Jan  3 2022 Axel Braun <axel.braun@gmx.de>
- Version 5.0.20 - Bugfix Release
* Mon Dec  6 2021 Axel Braun <axel.braun@gmx.de>
- Version 5.0.19 - Bugfix Release
* Fri Jun 18 2021 Axel Braun <axel.braun@gmx.de>
- Version 5.0.18 - Bugfix Release
* Sun May 16 2021 Axel Braun <axel.braun@gmx.de>
- Version 5.0.17 - Bugfix Release
* Sat Feb 27 2021 Andreas Stieger <andreas.stieger@gmx.de>
- add upstream signing key and validate source signature
* Sun Jan 24 2021 Axel Braun <axel.braun@gmx.de>
- Adaption to new python-macros
* Wed Nov 11 2020 Axel Braun <axel.braun@gmx.de>
- Version 5.0.16 - Bugfix Release
* Tue Oct 20 2020 Axel Braun <axel.braun@gmx.de>
- Version 5.0.15 - Bugfix Release
* Thu Aug 20 2020 Axel Braun <axel.braun@gmx.de>
- Version 5.0.14 - Bugfix Release
* Sat May 16 2020 Axel Braun <axel.braun@gmx.de>
- Version 5.0.13 - Bugfix Release
* Fri May  1 2020 Axel Braun <axel.braun@gmx.de>
- Version 5.0.12 - Bugfix Release
* Sat Apr  4 2020 Axel Braun <axel.braun@gmx.de>
- Version 5.0.11 - Bugfix Release
* Fri Jan 10 2020 Axel Braun <axel.braun@gmx.de>
- Version 5.0.10 - Bugfix Release
* Thu Nov 21 2019 Axel Braun <axel.braun@gmx.de>
- version 5.0.9 (GNU Health 3.6 series)
* Mon Nov 11 2019 Axel Braun <axel.braun@gmx.de>
- Version 4.6.11 - Bugfix Release
* Fri Jul 12 2019 Axel Braun <axel.braun@gmx.de>
- Version 4.6.10 - Bugfix Release
* Wed Feb 20 2019 Axel Braun <axel.braun@gmx.de>
- Version 4.6.9 - Bugfix Release
* Mon Jan  7 2019 Axel Braun <axel.braun@gmx.de>
- Version 4.6.8 - Bugfix Release
* Mon Dec 10 2018 Axel Braun <axel.braun@gmx.de>
- Version 4.6.7 - Bugfix Release
* Tue Nov 13 2018 Axel Braun <axel.braun@gmx.de>
- Version 4.2.10 - Bugfix Release
* Mon Sep 24 2018 Axel Braun <axel.braun@gmx.de>
- Version 4.2.9 - Bugfix Release
* Sat May 12 2018 axel.braun@gmx.de
- Version 4.2.8 - Bugfix Release
* Thu Apr  5 2018 axel.braun@gmx.de
- Version 4.2.7 - Bugfix Release
* Wed Mar 21 2018 axel.braun@gmx.de
- Version 4.2.6 - Bugfix Release
* Fri Mar  2 2018 axel.braun@gmx.de
- Version 4.2.5 - Bugfix Release
* Thu Nov  9 2017 axel.braun@gmx.de
- Version 4.2.4 - Bugfix Release
* Wed Oct  4 2017 axel.braun@gmx.de
- Version 4.2.3 - Bugfix Release
* Thu Aug 10 2017 axel.braun@gmx.de
- Version 4.2.2
* Tue Jun  6 2017 axel.braun@gmx.de
- Version 4.2.1
* Mon Nov 28 2016 axel.braun@gmx.de 
- Tryton Release 4.2
* Mon May  2 2016 axel.braun@gmx.de 
- Tryton Release 4.0
* Mon Oct 19 2015 axel.braun@gmx.de 
- Tryton Release 3.8
* Wed Apr 15 2015 axel.braun@gmx.de 
- Tryton Release 3.6
  %%changelog
* Thu May  2 2013 axel.braun@gmx.de
- initial build on OBS
